@@ -56,13 +56,13 @@ docroot = config.get(section, 'DocumentRoot')
 file_read = open(docroot + '/configuration.php',"r")
 contents = file_read.read()
 file_read.close()
-for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*([a-zA-Z-_\'\"\.0-9@]+)\s*;", contents):
+for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*([a-zA-Z-_\'\"\~\+\.0-9@]+)\s*;", contents):
   data['joomla'][m.group(1)] = m.group(2).strip(" \'\"\t")
 
 file_read = open(docroot + '/hubconfiguration.php',"r")
 contents = file_read.read()
 file_read.close()
-for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*([a-zA-Z-_\\\,\=\!\/\:\'\"\.0-9@]+)\s*;", contents):
+for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*([a-zA-Z-_\\\,\=\!\/\~\+\:\'\"\.0-9@\+]+)\s*;", contents):
   data['hubzero'][m.group(1)] = string.replace(m.group(2).strip(" \'\"\t"),"\\'","'")
 
 mysql_host = data['joomla']['host']
